@@ -103,9 +103,6 @@ void si_init_resource_fields(struct si_screen *sscreen, struct si_resource *res,
    if (sscreen->debug_flags & DBG(NO_WC))
       res->flags &= ~RADEON_FLAG_GTT_WC;
 
-   if (res->b.b.flags & SI_RESOURCE_FLAG_READ_ONLY)
-      res->flags |= RADEON_FLAG_READ_ONLY;
-
    if (res->b.b.flags & SI_RESOURCE_FLAG_32BIT)
       res->flags |= RADEON_FLAG_32BIT;
 
@@ -115,9 +112,9 @@ void si_init_resource_fields(struct si_screen *sscreen, struct si_resource *res,
    if (res->b.b.flags & PIPE_RESOURCE_FLAG_SPARSE)
       res->flags |= RADEON_FLAG_SPARSE;
 
-   /* For higher throughput and lower latency over PCIe assuming sequential access.
-    * Only CP DMA and optimized compute benefit from this.
-    * GFX8 and older don't support RADEON_FLAG_GL2_BYPASS.
+   /* For bypassing GL2 for performance reasons (not being slowed down by GL2, and not slowing down
+    * parallel GL2 traffic) such as asynchronous DRI prime blits, or when coherency with non-GL2
+    * clients is required, such as with GFX12. GFX8 and older don't support RADEON_FLAG_GL2_BYPASS.
     */
    if (sscreen->info.gfx_level >= GFX9 &&
        res->b.b.flags & SI_RESOURCE_FLAG_GL2_BYPASS)
@@ -135,7 +132,7 @@ void si_init_resource_fields(struct si_screen *sscreen, struct si_resource *res,
        * because they might never be moved back again. If a buffer is large enough,
        * upload data by copying from a temporary GTT buffer.
        */
-      if (sscreen->info.has_dedicated_vram &&
+      if (sscreen->info.has_dedicated_vram && !sscreen->info.all_vram_visible &&
           !res->b.cpu_storage && /* TODO: The CPU storage breaks this. */
           size >= sscreen->options.max_vram_map_size)
          res->b.b.flags |= PIPE_RESOURCE_FLAG_DONT_MAP_DIRECTLY;
@@ -644,6 +641,7 @@ static struct pipe_resource *si_buffer_from_user_memory(struct pipe_screen *scre
    }
 
    buf->gpu_address = ws->buffer_get_virtual_address(buf->buf);
+   buf->bo_size = templ->width0;
    return &buf->b.b;
 }
 
